"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const testing_1 = require("@nestjs/testing");
const oso_module_1 = require("../oso.module");
const oso_service_1 = require("../oso.service");
const oso_class_decorator_1 = require("../oso-class.decorator");
const oso_metadata_storage_1 = require("../oso-metadata.storage");
describe('OsoService', () => {
    let testApp;
    let TestClass = class TestClass {
    };
    TestClass = tslib_1.__decorate([
        (0, oso_class_decorator_1.OsoClass)()
    ], TestClass);
    beforeEach(() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const mod = yield testing_1.Test.createTestingModule({
            imports: [oso_module_1.OsoModule.forRoot()],
        }).compile();
        testApp = mod.createNestApplication();
        yield testApp.init();
    }));
    it('should return a bool on isAllowed', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const service = testApp.get(oso_service_1.OsoService);
        jest.spyOn(service, 'isAllowed').mockImplementation(() => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return true; }));
        expect(yield service.isAllowed('', '', '')).toBe(true);
    }));
    it('should register TestClass', () => {
        const classes = oso_metadata_storage_1.OsoMetadataStorage.getClasses();
        expect(classes).toContain(TestClass);
    });
    it('should load a file (deprecated)', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const mod = yield testing_1.Test.createTestingModule({
            imports: [
                oso_module_1.OsoModule.forRoot({
                    loadFile: `${__dirname}/rule1.polar`,
                }),
            ],
        }).compile();
        const loadFileApp = mod.createNestApplication();
        const service = loadFileApp.get(oso_service_1.OsoService);
        const func = jest
            .spyOn(service, 'loadFiles')
            .mockImplementation(() => tslib_1.__awaiter(void 0, void 0, void 0, function* () { }));
        yield loadFileApp.init();
        expect(func).toBeCalledTimes(1);
    }));
    it('should load a file', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const mod = yield testing_1.Test.createTestingModule({
            imports: [
                oso_module_1.OsoModule.forRoot({
                    loadFiles: [`${__dirname}/rule1.polar`],
                }),
            ],
        }).compile();
        const loadFileApp = mod.createNestApplication();
        const service = loadFileApp.get(oso_service_1.OsoService);
        const func = jest
            .spyOn(service, 'loadFiles')
            .mockImplementation(() => tslib_1.__awaiter(void 0, void 0, void 0, function* () { }));
        yield loadFileApp.init();
        expect(func).toBeCalledTimes(1);
    }));
    it('should load files', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const mod = yield testing_1.Test.createTestingModule({
            imports: [
                oso_module_1.OsoModule.forRoot({
                    loadFiles: [`${__dirname}/rule1.polar`, `${__dirname}/rule2.polar`],
                }),
            ],
        }).compile();
        const loadFileApp = mod.createNestApplication();
        const service = loadFileApp.get(oso_service_1.OsoService);
        const func = jest
            .spyOn(service, 'loadFiles')
            .mockImplementation(() => tslib_1.__awaiter(void 0, void 0, void 0, function* () { }));
        yield loadFileApp.init();
        expect(func).toBeCalledTimes(1);
    }));
    it('should load a file using regex (deprecated)', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const mod = yield testing_1.Test.createTestingModule({
            imports: [
                oso_module_1.OsoModule.forRoot({
                    loadFile: './**/*.polar',
                }),
            ],
        }).compile();
        const loadFileApp = mod.createNestApplication();
        const service = loadFileApp.get(oso_service_1.OsoService);
        const func = jest
            .spyOn(service, 'loadFiles')
            .mockImplementation(() => tslib_1.__awaiter(void 0, void 0, void 0, function* () { }));
        yield loadFileApp.init();
        expect(func).toBeCalledTimes(1);
    }));
    it('should load files using regex', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const mod = yield testing_1.Test.createTestingModule({
            imports: [
                oso_module_1.OsoModule.forRoot({
                    loadFiles: ['./**/*.polar'],
                }),
            ],
        }).compile();
        const loadFileApp = mod.createNestApplication();
        const service = loadFileApp.get(oso_service_1.OsoService);
        const func = jest
            .spyOn(service, 'loadFiles')
            .mockImplementation(() => tslib_1.__awaiter(void 0, void 0, void 0, function* () { }));
        yield loadFileApp.init();
        expect(func).toBeCalledTimes(1);
    }));
    it('should load strings', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const mod = yield testing_1.Test.createTestingModule({
            imports: [
                oso_module_1.OsoModule.forRoot({
                    loadStr: 'allow(_a, _b, _c);',
                }),
            ],
        }).compile();
        const loadFileApp = mod.createNestApplication();
        const service = loadFileApp.get(oso_service_1.OsoService);
        const func = jest
            .spyOn(service, 'loadStr')
            .mockImplementation(() => tslib_1.__awaiter(void 0, void 0, void 0, function* () { }));
        yield loadFileApp.init();
        expect(func).toBeCalled();
    }));
});
